========================
Neo 0.14.3 release notes
========================

13 October 25

This release of Neo includes many bug fixes in various IOs with an eye to a 1.0 release.

See all `pull requests`_ included in this release and the `list of closed issues`_.


Repository Clean-up
-------------------

The :code:`setup.py` has been removed from the repo as installation using setup.py is deprecated by setuptools.


Documentation Updates
---------------------

We updated the documentation to make use of the new eBRAINS URLs.


Bug fixes and improvements in IO modules
----------------------------------------

Bug fixes and/or improvements have been made to :code:`BlackRockIO`, :code:`NeuroNexusIO`, :code:`OpenEphysBinaryIO`, :code:`BiocamIO`, :code:`SpikeGadgetsIO`, :code:`NeuralynxIO`, 
:code:`SpikeGLXIO`, and :code:`BrainvisionIO`.


Acknowledgements
----------------

Thanks to Heberto Mayorquin, Zach McKenzie, Andrew Davison, Alessio Buccino, Christian Kothe, and Ariel Burman.

.. _`pull requests` : https://github.com/NeuralEnsemble/python-neo/pulls?q=is%3Apr+is%3Aclosed+milestone%3A0.14.3

.. _`list of closed issues` : https://github.com/NeuralEnsemble/python-neo/issues?q=is%3Aissue%20state%3Aclosed%20milestone%3A0.14.3